<?php

/**
* Plugin zum Verwalten eines Gruppenkalenders
*
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2008 Jan Kulmann <jankul@zmml.uni-bremen.de>
// ATTENTION: Please send ALL bug reports and security leaks directly to the author.
//            Thx!
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+


require_once("lib/visual.inc.php"); // fuer CSS etc.
require_once('lib/classes/Avatar.class.php');
require_once('vendor/flexi/template_factory.php');
require_once("classes/GkConfig.class.php");
require_once("classes/DBM.class.php");
require_once("classes/DateController.class.php");
require_once("classes/Import.class.php");

class GruppenkalenderPlugin extends AbstractStudIPStandardPlugin {

	var $tage; // = array("0"=>"Montag", "1"=>"Dienstag", "2"=>"Mittwoch", "3"=>"Donnerstag", "4"=>"Freitag", "5"=>"Samstag", "6"=>"Sonntag");
	var $monate; // = array("1"=>"Januar","2"=>"Februar","3"=>"M&auml;rz","4"=>"April","5"=>"Mai","6"=>"Juni","7"=>"Juli","8"=>"August","9"=>"September","10"=>"Oktober","11"=>"November","12"=>"Dezember");
	var $php_tage; // = array("1"=>"Montag", "2"=>"Dienstag", "3"=>"Mittwoch", "4"=>"Donnerstag", "5"=>"Freitag", "6"=>"Samstag", "0"=>"Sonntag");
	var $php_tage_short; // = array("1"=>"Mo", "2"=>"Di", "3"=>"Mi", "4"=>"Do", "5"=>"Fr", "6"=>"Sa", "0"=>"So");
	//var $date_colors = array('grau'=>'#ECECEC','rot'=>'#FF0000','pink'=>'#FFC0C0','orange'=>'#F8B524','gelb'=>'#FFFF00','grn'=>'#00FF00','hellblau'=>'#00FFFF','blau'=>'#0000FF','dunkelblau'=>'#0000C0','violett'=>'#C000C0','wei'=>'#FFFFFF');
	//var $date_colors = array('grau'=>'#C0C0C0','rot'=>'#FF0000','rosa'=>'#FFC0C0','orange'=>'#F8B524','gelb'=>'#FFFF00','grn'=>'#00FF00','dunkelgrn'=>'#00C000','hellgrn'=>'#C0FFC0','trkis'=>'#61FFC9','hellblau'=>'#00FFFF','violett'=>'#C000C0','pink'=>'#FF80FF','wei'=>'#FFFFFF');
	var $date_colors;
	var $config;
	var $dbm;
	var $dc;
	var $template_path;
	var $factory;
	var $range_id;


	function GruppenkalenderPlugin(){
		parent::AbstractStudIPStandardPlugin();

		$this->template_path = dirname(__FILE__) . '/templates/flexi';
		$this->factory = new Flexi_TemplateFactory($this->template_path);
		include_once(dirname(__FILE__) . '/include/config.inc.php');
		$this->date_colors = $DATE_COLORS;
		$this->tage = $TAGE;
		$this->monate = $MONATE;
		$this->php_tage = $PHP_TAGE;
		$this->php_tage_short = $PHP_TAGE_SHORT;
		$this->range_id = $GLOBALS['SessSemName'][1];
		//$this->setPluginIconName('edit_transparent.gif');
		$this->config = new GkConfig($GLOBALS['auth']->auth['uid'], $this->range_id);
		$this->dbm = new DBM(&$this->config);
		$this->dc = new DateController(&$this->dbm, &$this->config, $this->range_id, &$this);
		
		if (!$GLOBALS['modus'] && !$GLOBALS['plugin_subnavi_params']) {
			//$GLOBALS['plugin_subnavi_params'] = "daily_view";
			$GLOBALS['plugin_subnavi_params'] = str_replace('day','dai',$this->config->get('start_view')).'ly_view';
		}
		$modus2 = trim($_REQUEST['modus2']);
		if ($modus2) {
			$GLOBALS["plugin_subnavi_params"] = $modus2;
		}
	}
	
	function setPluginpath($newpath){
		parent::setPluginpath($newpath);
		$this->buildMenu();
	}
	
	function buildMenu(){
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		$tab = new PluginNavigation();
		$tab->setDisplayname("Gruppenkalender");
		$subnav0 = new PluginNavigation();
                $subnav0->setDisplayname("Tag");
                $subnav0->setLinkParam("daily_view");
                $subnav0->addLinkParam("datum", $datum);
                $tab->addSubmenu($subnav0);
		$subnav = new PluginNavigation();
                $subnav->setDisplayname("Woche");
                $subnav->setLinkParam("weekly_view");
                $subnav->addLinkParam("datum", $datum);
                $tab->addSubmenu($subnav);
		$subnav2 = new PluginNavigation();
                $subnav2->setDisplayname("Monat");
                $subnav2->setLinkParam("monthly_view");
                $subnav2->addLinkParam("datum", $datum);
                $tab->addSubmenu($subnav2);
		$subnav6 = new PluginNavigation();
                $subnav6->setDisplayname("Jahr");
                $subnav6->setLinkParam("yearly_view");
                $subnav6->addLinkParam("datum", $datum);
                $tab->addSubmenu($subnav6);
		$subnav7 = new PluginNavigation();
                $subnav7->setDisplayname("Listenansicht");
                $subnav7->setLinkParam("list_view_form");
                $subnav7->addLinkParam("datum", $datum);
                $tab->addSubmenu($subnav7);

		if ($GLOBALS['perm']->have_studip_perm('autor', $this->range_id)) {
			$subnav3 = new PluginNavigation();
        	        $subnav3->setDisplayname("Neuer Termin");
	                $subnav3->setLinkParam("new_date");
	                $subnav3->addLinkParam("datum", $datum);
        	        $tab->addSubmenu($subnav3);
		
			$subnav4 = new PluginNavigation();
        	        $subnav4->setDisplayname("Import");
	                $subnav4->setLinkParam("import");
	                $subnav4->addLinkParam("datum", $datum);
        	        $tab->addSubmenu($subnav4);

			$subnav6 = new PluginNavigation();
        	        $subnav6->setDisplayname("Export");
	                $subnav6->setLinkParam("export");
	                $subnav6->addLinkParam("datum", $datum);
        	        $tab->addSubmenu($subnav6);

			$subnav5 = new PluginNavigation();
        	        $subnav5->setDisplayname("Optionen");
	                $subnav5->setLinkParam("options");
	                $subnav5->addLinkParam("datum", $datum);
        	        $tab->addSubmenu($subnav5);

		}

		$this->setNavigation($tab); 
	}

	function getPluginname() {
		return "Gruppenkalender";
	}

	function createInfoBox ($imgLogo, $items, $title) {
                $infobox = array (array ("kategorie" => $title, "eintrag"   => $items));
                return print_infobox ($infobox, $imgLogo, YES);
        }


	function kill_tags($text) {
		$pattern = array("/\[img(.*)\](.*?)/i");
		$replace = array("$1");
		return preg_replace($pattern, $replace, $text);
	}

	function show_import_form() {
		$datum = trim($_REQUEST['datum']);
                if (!$datum) $datum = time();

		$items = array(array ("icon" => "i.gif", "text" => "Importieren Sie Termine aus anderen Kalendern wie z.B. Outlook oder FirstClass."),
                		array ("icon" => "ausruf_small3.gif", "text" => "Beachten Sie die Vorgaben f&uuml;r die Import-Dateien. Nach dem Absenden erhalten Sie eine zusammenfassende &Uuml;bersicht aller Termine, die importiert werden sollen. Anschlie&szlig;end haben Sie noch die M&ouml;glichkeit, einzelne Termine vor dem Import auszuschlie&szlig;en."));
		$box = $this->createInfoBox("schedules.jpg",$items, "Termine importieren");

		include('templates/import_form.tpl');
	}

	function show_export_form() {
		$datum = trim($_REQUEST['datum']);
                if (!$datum) $datum = time();
		$range_id = $this->range_id;
		$von = $datum;
		$bis = strtotime('+1 day', $datum);

		$items = array(array ("icon" => "i.gif", "text" => "Exportieren Sie Termine in das iCalendar-Format zur Weiterverwendung in anderen Programmen."),
				array ("icon" => "popupkalender.gif", "text" => "Mit dem Kalendersymbol am Rand der Eingabezeilen k&ouml;nnen Sie bequem ein Datum ausw&auml;hlen."),
				array ("icon" => "info.gif", "text" => "Es empfiehlt sich, den Export-Zeitraum nicht zu gro&szlig; zu w&auml;hlen."));
		$box = $this->createInfoBox("export.jpg",$items, "Termine exportieren");

		include('templates/export_form.tpl');
	}

	function show_list_form() {
		$datum = trim($_REQUEST['datum']);
                if (!$datum) $datum = time();
		$range_id = $this->range_id;
		$von = $datum;
		$bis = strtotime('+1 day', $datum);

		$items = array(array ("icon" => "i.gif", "text" => "Hier erhalten Sie Listen von Terminen in dem von Ihnen angegeben Zeitraum."));
		$box = $this->createInfoBox("schedules.jpg",$items, "Listenansicht");

		include('templates/list_form.tpl');
	}

	function show_options_form() {
		$datum = trim($_REQUEST['datum']);
                if (!$datum) $datum = time();
		$t = $this->config->getArray();

		$cssSw=new cssClassSwitcher;

		$items = array(array ("icon" => "i.gif", "text" => "Passen Sie den Kalender hier an Ihre pers&ouml;nlichen Bed&uuml;rfnisse an."),
				array ("icon" => "ausruf_small3.gif", "text" => "Beachten Sie, da&szlig; eingeblendete Termine nur f&uuml; Sie sichtbar sind."),
				array ("icon" => "nachricht1.gif", "text" => "Benachrichtigungen werden bei Neueintrag oder &Auml;nderung verschickt, sofern hier aktiviert."));
		$box = $this->createInfoBox("modules.jpg",$items, "Kalender anpassen");

		include('templates/options_form.tpl');
	}
	
	function show_serie_save_form($termin_id) {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();
		$t = array();
		$t['von_t'] = trim($_REQUEST['von_t']);
		$t['von_m'] = trim($_REQUEST['von_m']);
		$t['von_j'] = trim($_REQUEST['von_j']);
		$t['von_h'] = trim($_REQUEST['von_h']);
		$t['von_i'] = trim($_REQUEST['von_i']);

		$t['bis_t'] = trim($_REQUEST['bis_t']);
		$t['bis_m'] = trim($_REQUEST['bis_m']);
		$t['bis_j'] = trim($_REQUEST['bis_j']);
		$t['bis_h'] = trim($_REQUEST['bis_h']);
		$t['bis_i'] = trim($_REQUEST['bis_i']);

		$t['ort'] = trim($_REQUEST['ort']);
		$t['title'] = trim($_REQUEST['title']);
		$t['content'] = trim($_REQUEST['content']);
		$t['color'] = trim($_REQUEST['color']);
		$t['write_perm'] = trim($_REQUEST['write_perm']);
		$t['write_perm_group'] = trim($_REQUEST['write_perm_group']);
		$t['fulltime'] = $_REQUEST['fulltime'];

		$cssSw=new cssClassSwitcher;
		
		include('templates/serie_save_form.tpl');
	}

	function show_serie_delete_form($termin_id) {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		$cssSw=new cssClassSwitcher;
		$studipticket = Seminar_Session::get_ticket();

		include('templates/serie_delete_form.tpl');
	}

	function show_termin_new_form() {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		$t = new DateObject();
		$tag_datum = trim($_REQUEST['tag']);
		list($tag, $monat, $jahr) = explode(".",$tag_datum);

		// fuer drag'n'drop
		if ($tag && $monat && $jahr && $von_h && $von_i && $bis_h && $bis_i) {
			$von_h = trim($_REQUEST['von_h']);
			$von_i = trim($_REQUEST['von_i']);
			$bis_h = trim($_REQUEST['bis_h']);
			$bis_i = trim($_REQUEST['bis_i']);
			$von = mktime($von_h, $von_i, 0, $monat, $tag, $jahr);
			$bis = mktime($bis_h, $bis_i, 0, $monat, $tag, $jahr);
		} else {
			$von = mktime(date('H',time()), date('i',time()), 0, date('m',$datum), date('d',$datum), date('Y',$datum));
			$bis = mktime(date('H',strtotime('+2 hours', time())), date('i',strtotime('+2 hours', time())), 0, date('m',$datum), date('d',$datum), date('Y',$datum));
		}
		
		$t->setVon($von);
		$t->setBis($bis);

		$tt = array();
		$tt['colors'] = $this->date_colors;
		$tt['gruppen'] = $this->dbm->getStatusgruppen($this->range_id, $GLOBALS['auth']->auth['uid']);

		$items = array(array ("icon" => "i.gif", "text" => "Legen Sie neue Termine an."),
				array ("icon" => "info.gif", "text" => "F&uuml;r ganzt&auml;gige Ereignisse empfiehlt es sich, den Schalter 'Ganzt&auml;gig' auf 'Ja' zu setzen, um die &Uuml;bersicht zu verbessern."),
				array ("icon" => "popupkalender.gif", "text" => "Mit dem Kalendersymbol am Rand der Eingabezeilen k&ouml;nnen Sie bequem ein Datum ausw&auml;hlen."),
				array ("icon" => "nachricht1.gif", "text" => "Benachrichtigungen werden bei Neueintrag oder &Auml;nderung verschickt. Empfangen werden sie nur, wenn dies in den Optionen aktiviert wurde."));
		$box = $this->createInfoBox("dates.jpg",$items, "Termin anlegen");

		include('templates/termin_edit_form.tpl');
        }

	function show_termin_edit_form($termin_id) {
		$datum = $_REQUEST['datum'];
		if (!$datum) $datum = time();

		$t = new DateObject();
		$t->load($termin_id);

		$tt = array();
		$tt['colors'] = $this->date_colors;
		$tt['gruppen'] = $this->dbm->getStatusgruppen($this->range_id, $GLOBALS['auth']->auth['uid']);

		if ($t->getSerieId()) {
			$del_modus = "delete_termin_really";
			$serien_info = $this->dbm->getSerienInfo($t->getSerieId());
		} else {
			$del_modus = "delete_termin";
		}
		$studipticket = Seminar_Session::get_ticket();

		$items = array(array ("icon" => "i.gif", "text" => "Bearbeiten Sie hier den Termin."),
				array ("icon" => "info.gif", "text" => "F&uuml;r ganzt&auml;gige Ereignisse empfiehlt es sich, den Schalter 'Ganzt&auml;gig' auf 'Ja' zu setzen, um die &Uuml;bersicht zu verbessern."),
                                array ("icon" => "popupkalender.gif", "text" => "Mit dem Kalendersymbol am Rand der Eingabezeilen k&ouml;nnen Sie bequem ein Datum ausw&auml;hlen."),
                                array ("icon" => "nachricht1.gif", "text" => "Benachrichtigungen werden bei Neueintrag oder &Auml;nderung verschickt. Empfangen werden sie nur, wenn dies in den Optionen aktiviert wurde."));
		$box = $this->createInfoBox("dates.jpg",$items, "Termin bearbeiten");

                include('templates/termin_edit_form.tpl');
        }

	function verify_import($termin_arr) {
		$cssSw=new cssClassSwitcher;

		include('templates/import_verify_form.tpl');
	}

	function create_date_series($range_id) {
		$only_workdays = ($_REQUEST['only_workdays'] == 1 ? TRUE : FALSE);
		$rhythmus = trim($_REQUEST['rhythmus']);
		$rhythmus_abstand = $_REQUEST['rhythmus_abstand'];
		$von_abs = mktime($_REQUEST['von_h'],$_REQUEST['von_i'],0,$_REQUEST['von_m'],$_REQUEST['von_t'],$_REQUEST['von_j']);
                $bis_abs = mktime($_REQUEST['bis_h'],$_REQUEST['bis_i'],0,$_REQUEST['bis_m'],$_REQUEST['bis_t'],$_REQUEST['bis_j']);

		$current_date = $von_abs;
		$counter = 0;

		$serie_id = md5(uniqid($range_id.time()));

		while ($current_date <= $bis_abs) {
			if ($only_workdays && (date("w",$current_date) == '0' || date("w",$current_date) == '6')) {
				$current_date = strtotime("+".$rhythmus_abstand." ".$rhythmus.($rhythmus_abstand > 1 ? "s" : ""), $current_date);
				continue;
			}
			$bis = mktime($_REQUEST['bis_h'],$_REQUEST['bis_i'],0,date('m',$current_date),date('d',$current_date),date('Y',$current_date));
			$new_id = md5(uniqid(time().$GLOBALS['auth']->auth['uid']));
			$t = new DateObject();
			$t->setTerminId($new_id);
			$t->setRangeId($range_id);
			$t->setVon($current_date);
			$t->setBis($bis);
			$t->setOrt(mysql_real_escape_string(trim($_REQUEST['ort'])));
			$t->setUserId($GLOBALS['auth']->auth['uid']);
			$t->setTitle(mysql_real_escape_string(trim($_REQUEST['title'])));
			$t->setContent(mysql_real_escape_string(trim($_REQUEST['content'])));
			$t->setColor(mysql_real_escape_string(trim($_REQUEST['color'])));
			$t->setWritePerm(trim($_REQUEST['write_perm']));
			$t->setWritePermGroup(trim($_REQUEST['write_perm_group']));
			$t->setFulltime(0);
			$t->setSerieId($serie_id);
			$t->insert();

			$counter++;
			$current_date = strtotime("+".$rhythmus_abstand." ".$rhythmus.($rhythmus_abstand > 1 ? "s" : ""), $current_date);
		}
		if ($counter > 0)
			$this->dc->notifyUsers($serie_id, "serie", "new");

		return $counter;
	}

	function show() {
		$GLOBALS['perm']->check('autor');
		$db = new DB_Seminar();
                $db2 = new DB_Seminar();
                $range_id = $this->range_id;
		$modus = trim($_REQUEST['modus']);
		$msg = "";
			
		if ($GLOBALS['perm']->have_studip_perm('autor', $range_id)) {
			if ($modus == "delete_termin_really" && check_ticket($_REQUEST['ticket'])) {
				$t = new DateObject();
				$t->load($_REQUEST['termin_id']);
				$serie_delete_mode = trim($_REQUEST['serie_delete_mode']);
				$termin_id = $_REQUEST['termin_id'];
				if ($t->getSerieId() != "" && $serie_delete_mode == "") {
					$this->show_serie_delete_form($termin_id);
				} else {
					if ($serie_delete_mode == "only_one" || ($t->getSerieId() == "" && $serie_delete_mode == "")) {
						$t = new DateObject();
						$t->load($termin_id);
						$t->delete();
						unset($t);
						$msg .= "msgDer Termin wurde gel&ouml;scht.";
					} else if ($serie_delete_mode == "all") {
						$this->dbm->deleteSerie($termin_id);
						$msg .= "msgDie Terminserie wurde gel&ouml;scht.";
					} else if ($serie_delete_mode == "from_now") {
						$this->dbm->deleteSerie($termin_id, $t->getVon());
						$msg .= "msgDie Terminserie wurde teilweise gel&ouml;scht.";
					}
					unset($modus);
				}
			}
			if ($modus == "import_termine" && $GLOBALS['datei'] && $GLOBALS['datei_size'] && $GLOBALS['datei_name']) {
				$import = new Import();
                                $termin_arr = $import->parse_import_datei($GLOBALS['datei'], $GLOBALS['datei_size'], $GLOBALS['datei_name'], trim($_REQUEST['datei_format']));
				if (is_array($termin_arr)) {
					$this->verify_import($termin_arr);
				} else {
					$msg .= $termin_arr;
					unset($modus);
				}
			}
			if ($modus == "import_termine_really" && is_array($GLOBALS['termin_arr'])) {
					foreach ($GLOBALS['termin_arr'] as $tt) {
						$ta = unserialize(base64_decode($tt));
						$t = new DateObject();
						$new_id = md5(uniqid(time().$GLOBALS['auth']->auth['uid']));
						$t->setTerminId($new_id);
						$t->setRangeId($range_id);
						$t->setTitle(mysql_real_escape_string(trim($ta['title'])));
						$t->setContent(mysql_real_escape_string(trim($ta['content'])));
						$t->setOrt(mysql_real_escape_string(trim($ta['location'])));
						$t->setVon($ta['start']);
						$t->setBis($ta['end']);
						$t->insert();
						unset($t);
					}
					$msg .= "msg".sprintf("%s Termine wurden importiert.",count($GLOBALS['termin_arr']));
	
			}
			if ($modus == "save_termin") {
				$von = mktime($_REQUEST['von_h'],$_REQUEST['von_i'],0,$_REQUEST['von_m'],$_REQUEST['von_t'],$_REQUEST['von_j']);
				$bis = mktime($_REQUEST['bis_h'],$_REQUEST['bis_i'],0,$_REQUEST['bis_m'],$_REQUEST['bis_t'],$_REQUEST['bis_j']);

				if ($bis <= $von) {
					$msg .= "errorDer End-Zeitpunkt darf nicht hinter dem Start-Zeitpunkt liegen!";
				} else {
					$termin_id = trim($_REQUEST['termin_id']);
					if (!$termin_id) {
						if ($_REQUEST['termin_art'] == 'single') {
							$new_id = md5(uniqid(time().$GLOBALS['auth']->auth['uid']));
							$t = new DateObject();
							$t->setTerminId($new_id);
							$t->setRangeId($range_id);
							$t->setVon($von);
							$t->setBis($bis);
							$t->setOrt(mysql_real_escape_string(trim($_REQUEST['ort'])));
							$t->setUserId($GLOBALS['auth']->auth['uid']);
							$t->setTitle(mysql_real_escape_string(trim($_REQUEST['title'])));
							$t->setContent(mysql_real_escape_string(trim($_REQUEST['content'])));
							$t->setColor(mysql_real_escape_string(trim($_REQUEST['color'])));
							$t->setWritePerm(trim($_REQUEST['write_perm']));
							$t->setWritePermGroup(trim($_REQUEST['write_perm_group']));
							$t->setFulltime($_REQUEST['fulltime']);
							$t->insert();

							$msg .= "msg"._("Der Termin wurde gespeichert.");
							$this->dc->notifyUsers($new_id, "single", "new");
						} else {
							$anz = $this->create_date_series($range_id);
							$msg .= ($anz > 0 ? "msg" : "error").sprintf(_("%d Termin(e) angelegt."),$anz)."";
						}
						unset($modus);
					} else {
						$t = new DateObject();
						$t->load($_REQUEST['termin_id']);
						if ($this->dbm->hasEditRights($range_id, $GLOBALS['auth']->auth['uid'], $t)) {
							$serie_save_mode = trim($_REQUEST['serie_save_mode']);
							if ($t->getSerieId() != "" && $serie_save_mode == "") {
								$this->show_serie_save_form($termin_id);
							} else {
								if ($serie_save_mode == "only_one" || ($t->getSerieId() == "" && $serie_save_mode == "")) {
									$t->setVon($von);
									$t->setBis($bis);
									$t->setOrt(mysql_real_escape_string(trim($_REQUEST['ort'])));
									$t->setUserId($GLOBALS['auth']->auth['uid']);
									$t->setTitle(mysql_real_escape_string(trim($_REQUEST['title'])));
									$t->setContent(mysql_real_escape_string(trim($_REQUEST['content'])));
									$t->setColor(mysql_real_escape_string(trim($_REQUEST['color'])));
									$t->setWritePerm(trim($_REQUEST['write_perm']));
									$t->setWritePermGroup(trim($_REQUEST['write_perm_group']));
									$t->setFulltime($_REQUEST['fulltime']);
									$t->save();
									$msg .= "msg"._("Der Termin wurde aktualisiert.")."";
									$this->dc->notifyUsers($t->getTerminId(), "single", "edit");
								} else if ($serie_save_mode == "all") {
									$this->dbm->updateSerie($_REQUEST['termin_id'],mysql_real_escape_string(trim($_REQUEST['title'])), 
										mysql_real_escape_string(trim($_REQUEST['content'])),mysql_real_escape_string(trim($_REQUEST['ort'])),
										trim($_REQUEST['color']), trim($_REQUEST['write_perm']), trim($_REQUEST['write_perm_group']),
										$von, $bis);
									$msg .= "msg"._("Die Terminserie wurde aktualisiert.")."";
									$this->dc->notifyUsers($t->getSerieId(), "serie", "edit");
								} else if ($serie_save_mode == "from_now") {
									$this->dbm->updateSerie($_REQUEST['termin_id'],mysql_real_escape_string(trim($_REQUEST['title'])), 
										mysql_real_escape_string(trim($_REQUEST['content'])),mysql_real_escape_string(trim($_REQUEST['ort'])),
										trim($_REQUEST['color']), trim($_REQUEST['write_perm']), trim($_REQUEST['write_perm_group']),
										$von, $bis, $t->getVon());
									$msg .= "msg"._("Die Terminserie wurde aktualisiert.")."";
									$this->dc->notifyUsers($t->getSerieId(), "serie", "edit");
								}
								unset($modus);
							}
						} else {
							$msg .= "error"._("Sie haben keine Berechtigung, diesen Termin zu ver&auml;ndern.")."";
							unset($modus);
						}
					}
				}
			}
			if ($modus == "edit_termin" && $_REQUEST['termin_id']) {
				$this->show_termin_edit_form($_REQUEST['termin_id']);
			}
			if ($modus == "delete_termin" && $_REQUEST['termin_id']) {
				$this->show_termin_edit_form($_REQUEST['termin_id']);
			}
			if ($modus == "save_options") {
				$this->config->set('start_time', trim($_REQUEST['start_time']));
				$this->config->set('include_sem_dates', trim($_REQUEST['include_sem_dates']));
				$this->config->set('include_tv_dates', trim($_REQUEST['include_tv_dates']));
				$this->config->set('include_calendar_dates', trim($_REQUEST['include_calendar_dates']));
				$this->config->set('only_own_dates', trim($_REQUEST['only_own_dates']));
				$this->config->set('quick_create_date', trim($_REQUEST['quick_create_date']));
				$this->config->set('tag_overlapping_dates', trim($_REQUEST['tag_overlapping_dates']));
				$this->config->set('start_view', trim($_REQUEST['start_view']));
				$this->config->set('use_pdf_colors', trim($_REQUEST['use_pdf_colors']));
				$this->config->set('receive_msg', trim($_REQUEST['receive_msg']));
				$this->config->set('sem_date_color', trim($_REQUEST['sem_date_color']));
				$this->config->set('tv_date_color', trim($_REQUEST['tv_date_color']));
				$this->config->set('cal_date_color', trim($_REQUEST['cal_date_color']));
				$this->config->save();
				$msg .= "msgDie Optionen wurden gespeichert";
				unset($modus);
			}
		} else {
			$msg = "errorSie haben keine Berechtigung, hier Daten zu ver&auml;ndern!";
		}

		if ($msg) {
			echo "<TABLE BORDER=\"0\">\n";
			parse_msg($msg);
			echo "</TABLE>\n";
		}


		if (!$modus) {
			if ($GLOBALS['plugin_subnavi_params'] == "daily_view") {
				$this->daily_view();
			} else if ($GLOBALS['plugin_subnavi_params'] == "weekly_view") {
				$this->weekly_view();
			} else if ($GLOBALS['plugin_subnavi_params'] == "monthly_view") {
				$this->monthly_view();
			} else if ($GLOBALS['plugin_subnavi_params'] == "yearly_view") {
				$this->yearly_view();
			} else if ($GLOBALS['plugin_subnavi_params'] == "list_view") {
				$this->show_list_view();
			} else if ($GLOBALS['plugin_subnavi_params'] == "list_view_form") {
				$this->show_list_form();
			} else if ($GLOBALS['plugin_subnavi_params'] == "new_date" && $GLOBALS['perm']->have_studip_perm('autor', $range_id)) {
				$this->show_termin_new_form();
			} else if ($GLOBALS['plugin_subnavi_params'] == "import" && $GLOBALS['perm']->have_studip_perm('autor', $range_id)) {
				$this->show_import_form();
			} else if ($GLOBALS['plugin_subnavi_params'] == "export" && $GLOBALS['perm']->have_studip_perm('autor', $range_id)) {
				$this->show_export_form();
			} else if ($GLOBALS['plugin_subnavi_params'] == "options" && $GLOBALS['perm']->have_studip_perm('autor', $range_id)) {
				$this->show_options_form();
			}
		}
	}

	function list_view($von, $bis) {
		$t_dates = $this->dbm->getDatesInRange($von, $bis, $this->range_id, FALSE, 'date ASC');
		$cssSw=new cssClassSwitcher;
		$template = $this->factory->open('listview');
                $template->set_attribute('cssSw', $cssSw);
       	        $template->set_attribute('items', $t_dates);
       	        $template->set_attribute('plugin_subnavi_params', $_REQUEST['plugin_subnavi_params']);
       	        $template->set_attribute('von', $von);
       	        $template->set_attribute('bis', $bis);
       	        $template->set_attribute('range_id', $this->range_id);
       	        $template->set_attribute('pdf_download_uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->getPluginpath()."/download.php?");
       	        $template->set_attribute('php_tage_short', $this->php_tage_short);
               	echo $template->render();
		die;
	}

	function show_list_view() {
		$datum = trim($_REQUEST['datum']);
                if (!$datum) $datum = time();
		$von = (int)$_REQUEST['start'];
		$bis = (int)$_REQUEST['end'];
		if ($bis <= $von) {
			$this->show_list_form();
		}
		include('templates/details.tpl');

		$this->list_view($von, $bis);
	}

	function yearly_view() {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		$prevyear = strtotime(date("01.01.Y", strtotime("-1 year", $datum)));
		$nextyear = strtotime(date("01.01.Y", strtotime("+1 year", $datum)));

		$link_zurueck = PluginEngine::getLink($this,array("datum"=>$prevyear, "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$link_vor = PluginEngine::getLink($this,array("datum"=>$nextyear, "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$today_link = PluginEngine::getLink($this,array("datum"=>time(), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$self_link = PluginEngine::getLink($this,array("plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));

		$first_day_in_year = strtotime(date("01.01.Y 00:00:00",$datum));
		$last_day_in_year = strtotime("+1 day",strtotime(date("31.12.Y 00:00:00",$datum)));

		include('templates/header_year.tpl');

		include('templates/details.tpl');

		if ($_REQUEST['listview'] == '1') {
			$this->list_view($first_day_in_year, $last_day_in_year);
		}

		$tag_weite = 90;
		$tag_hoehe = 25;
		$monat_hoehe = 30;
		$monat_weite = $tag_weite;
		$x = 0;
		$y = 0;
		$frame_hoehe = 850;
		$frame_weite = 1080;

		echo "<CENTER>\n";
		echo "<DIV STYLE=\"position:relative; width:".$frame_weite."px; min-width:".$frame_weite."px; max-width:".$frame_weite."px; height:".$frame_hoehe."px; min-height:".$frame_hoehe."px; max-height:".$frame_hoehe."px;\">\n";

		//$t_dates = $this->dbm->getDatesInRange(strtotime(date("01.01.Y 00:00:00",$datum)), strtotime("+1 day",strtotime(date("31.12.Y 00:00:00",$datum))), $this->range_id, FALSE);
		$t_dates = $this->dbm->getDatesInRange($first_day_in_year , $last_day_in_year, $this->range_id, FALSE);
		$t_dates_count_arr = array();
		foreach ($t_dates as $t) {
			$t_start = $t->getVon();
			$t_ende = $t->getBis();
			while ($t_start <= $t_ende) {
				$d = date("d.m.Y",$t_start);
				if ($t_dates_count_arr[$d]) $t_dates_count_arr[$d]++;
				else $t_dates_count_arr[$d] = 1;
				$t_start = strtotime("+1 day",$t_start);
			}
		}

		for ($month = 1; $month < 13; $month++) {
			$last_date = $this->dc->lastDayOfMonth(strtotime("01.".str_pad($month,2,"0",STR_PAD_LEFT).".".date("Y",$datum)));
			$current_date = strtotime("01.".str_pad($month,2,"0",STR_PAD_LEFT).".".date("Y",$datum));
			$counter = 1;
			$month_link = PluginEngine::getLink($this,array("datum"=>$current_date, "plugin_subnavi_params"=>"monthly_view"));

			include('templates/month_year.tpl');

			$y = $monat_hoehe;
			while ($current_date <= $last_date) {
				$von = strtotime(date("d.m.Y 00:00:00",$current_date));
	                        $bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$current_date)));

				$termin_texte = "";
				if ($anz = $t_dates_count_arr[date("d.m.Y",$current_date)]) {
					$termin_texte = "<IMG SRC=\"".$GLOBALS['ASSETS_URL']."/images/info.gif\" ALT=\"".$anz." Termin".($anz > 1 ? "e" : "")." vorhanden\" TITLE=\"".$anz." Termin".($anz > 1 ? "e" : "")." vorhanden\" onClick=\"updateDetails('".$von."','".$bis."','');\">";
				}
				$today = (date("d.m.Y",time()) == date("d.m.Y",$current_date));
				$wotag = $this->php_tage_short[date("w",$current_date)];
				$tag = date("j",$current_date);
				if (date("w",$current_date) == 0)
					$color = "#5D74A0";
				else if (date("w",$current_date) == 6)
					$color = "#9BACBC";
				else $color = "white";

				include('templates/single_yearday.tpl');

				$y += $tag_hoehe;
				$current_date = strtotime("+1 day",$current_date);
				$counter++;
			}
			$x += $tag_weite;
		}
		echo "</DIV>\n";
		echo "</CENTER>\n";

	}

	function monthly_view() {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		$prevmonth = strtotime(date("01.m.Y", strtotime("-1 month", $datum)));
		$nextmonth = strtotime(date("01.m.Y", strtotime("+1 month", $datum)));

		include('templates/details.tpl');
		
		$link_zurueck = PluginEngine::getLink($this,array("datum"=>$prevmonth, "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$link_vor = PluginEngine::getLink($this,array("datum"=>$nextmonth, "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$today_link = PluginEngine::getLink($this,array("datum"=>time(), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$self_link = PluginEngine::getLink($this,array("plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));

		include('templates/header_month.tpl');

		$last_date = $this->dc->lastDayOfMonth($datum);
		$last_day_in_month = $last_date;
		if (date("w", $last_date) != 0) $last_date = $this->dc->nextSunday($last_date);
		$current_date = $this->dc->firstDayOfMonth($datum);
		$first_day_in_month = $current_date;
		if (date("w",$current_date) != 1) $current_date = $this->dc->lastMonday($current_date);

		if ($_REQUEST['listview'] == '1') {
			$this->list_view($first_day_in_month, $last_day_in_month);
		}

		$counter = 0;
		$tag_weite = 150;
		$tag_hoehe = 150;
		$x = 0;
		$y = 0;
		$frame_hoehe = 1000;
		$frame_weite = 1050;

		echo "<CENTER>\n";
		echo "<DIV STYLE=\"position:relative; width:".$frame_weite."px; min-width:".$frame_weite."px; max-width:".$frame_weite."px; height:".$frame_hoehe."px; min-height:".$frame_hoehe."px; max-height:".$frame_hoehe."px;\">\n";

		while ($current_date <= $last_date) {
			$von = strtotime(date("d.m.Y 00:00:00",$current_date));
			$bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$current_date)));
			$t_dates = $this->dbm->getDatesInRange($von, $bis, $this->range_id, FALSE);

			if ($counter == 7) {
				$x = 0;
				$y += $tag_hoehe;
				$counter = 0;
			}
			$found = FALSE;
			$termin_texte = "";
			if (count($t_dates) > 0) {
				foreach ($t_dates as $t) {
					if (mktime(0,0,0,date('m',$current_date),date('d',$current_date),date('Y',$current_date)) > $t->getVon() ||
					    mktime(0,0,0,date('m',$current_date),date('d',$current_date) + 1 ,date('Y',$current_date)) < $t->getBis()) {
						//$t['editable'] = 2;
						//$anzeige_zeit = date("d.m.Y H:i",$t->getVon())." - ".date("d.m.Y H:i",$t->getBis());
						$anzeige_zeit = date("d.m.Y",$t->getVon())." - ".date("d.m.Y",$t->getBis());
					} else $anzeige_zeit = date("H:i",$t->getVon())." - ".date("H:i",$t->getBis());
					$template = $this->factory->open('single_date_month');
					$template->set_attribute('title', htmlReady($t->getTitle()));
					$template->set_attribute('weite', ($tag_weite -2));
					$template->set_attribute('color', $t->getColor());
					$template->set_attribute('von', $von);
					$template->set_attribute('bis', $bis);
					$template->set_attribute('termin_id', $t->getTerminId());
					$template->set_attribute('ort', htmlReady($t->getOrt()));
					$template->set_attribute('zeit', $anzeige_zeit);
					$termin_texte .= $template->render();
					$found = TRUE;
				}
			}
			$today = (date("d.m.Y",time()) == date("d.m.Y",$current_date));

			// for display purposes
			$color = ($current_date < $first_day_in_month || $current_date > $last_day_in_month ? "gray" : ($today ? "red" : "black"));			
			$tmp_tag_weite = $tag_weite - 2;
			
			$js = "onClick=\"updateDetails('".$von."','".$bis."','');\"";

			include('templates/single_monthday.tpl');

			$current_date = strtotime("+1 day",$current_date);
			$x += $tag_weite;
			$counter++;
		}
		echo "</DIV>\n";
		echo "</CENTER>\n";

	}

	function weekly_view() {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		//$this_monday = (date("w", $datum) != 1 ? $this->lastMonday($datum) : $datum);
		//$this_sunday = (date("w", $datum) != 0 ? $this->nextSunday($datum) : $datum);
		$this_monday = (date("w", $datum) != 1 ? $this->dc->lastMonday($datum) : $datum);
		$this_sunday = (date("w", $datum) != 0 ? $this->dc->nextSunday($datum) : $datum);

		//echo "<DIV STYLE=\"text-align:right; font-size:0.8em;\"><A HREF=\"".$GLOBALS['ABSOLUTE_URI_STUDIP'].$this->getPluginpath()."/download.php?datum=$datum&modus=week&range_id=".$GLOBALS['SessSemName'][1]."\" TARGET=\"pdf\">PDF-Export <IMG SRC=\"".$GLOBALS['ASSETS_URL']."/images/pdf-icon.gif\" BORDER=\"0\"></A></DIV>\n";
 
		include('templates/details.tpl');

		$link_zurueck = PluginEngine::getLink($this,array("datum"=>strtotime("-1 week", $datum), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$link_vor = PluginEngine::getLink($this,array("datum"=>strtotime("+1 week", $datum), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$today_link = PluginEngine::getLink($this,array("datum"=>time(), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$self_link = PluginEngine::getLink($this,array("plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));

		include('templates/header_week.tpl');

		$fulltime_dates = $this->dbm->getFulltimeDatesInRange($this_monday, $this_sunday, $this->range_id);

		$start_stunde = $this->config->get('start_time');
		$zeit_hoehe = 60;
		$zeit_weite = 50;
		$tag_weite = 150;
		$min_weite = floor($tag_weite / 4);
		$min_hoehe = 50;
		$wotag_hoehe = 40;
		$fulltime_hoehe = 18; // ein einzelner Ganztaagstermin
		$ganztag_hoehe = (count($fulltime_dates) > 0 ? (count($fulltime_dates) * $fulltime_hoehe > 100 ? 100 : count($fulltime_dates) * $fulltime_hoehe + 10) : 0); // der gesamte Ganztagscontainer
		$start_offset = $wotag_hoehe + $ganztag_hoehe; // wotag_hoehe + x, falls ganztgige Ternube vorhanden, sonst nur wtag_hoehe
		$frame_weite = $tag_weite * 7 + $zeit_weite;
		$frame_hoehe = (24 - $start_stunde) * $zeit_hoehe + $start_offset;

		if ($_REQUEST['listview'] == '1') {
			$this->list_view($this_monday, $this_sunday);
		}
		

		echo "<DIV ID=\"weekdrop\" STYLE=\"position:relative; width:".$frame_weite."px; min-width:".$frame_weite."px; max-width:".$frame_weite."px; height:".($frame_hoehe + 50)."px; min-height:".($frame_hoehe + 50)."px; max-height:".($frame_hoehe + 50)."px;\">\n";
		
		$weekdays = array();
		$this_day = $this_monday;
		while ($this_day < strtotime("+1 day",$this_sunday)) {
			array_push($weekdays, date("d.m.Y",$this_day));
			$this_day = strtotime("+1 day", $this_day);
		}

		$create_link = PluginEngine::getLink($this,array("datum"=>$datum,"plugin_subnavi_params"=>"new_date"));
		$abort_link = PluginEngine::getLink($this,array("datum"=>$datum,"plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		if ($this->config->get('quick_create_date'))
			include('templates/new_date_draggable.tpl');

		// Wochentage Montag - Sonntag
		$akt_tag = $this_monday;
		for ($i=0; $i<7; $i++) {
			$today = (date("d.m.Y",time()) == date("d.m.Y",$akt_tag));
			$wotag_x1 = ($i * $tag_weite) + $zeit_weite;

			include('templates/day_line_week.tpl');
			
			$day_link = PluginEngine::getLink($this,array("datum"=>$akt_tag,"plugin_subnavi_params"=>"daily_view"));
			$day_format = ($today ? "font-weight:bold; color:red;" : "");
			include('templates/day_week.tpl');
			$akt_tag = strtotime("+1 day", $akt_tag);
			if ($today) {
				include('templates/actual_day_week.tpl');
			}
		}
	
		// Falls es ganztaegige Termine gibt, werden sie gesondert dargestellt
		if (count($fulltime_dates) > 0) {
			$zeit_y1 = $wotag_hoehe;
			$zeit_y2 = $start_offset;
			include('templates/hour_wholeday_week.tpl');
			include('templates/wholeday_container_week.tpl');
			$y1 = 0;
			foreach ($fulltime_dates as $t) {
				$start_tag = (date('z',$t->getVon()) < date('z',$this_monday) ? date('w',$this_monday) : date('w',$t->getVon()));
				$end_tag = (date('z',$t->getBis()) > date('z',$this_sunday) ? date('w',$this_sunday) : date('w',$t->getBis()));
				if ($start_tag == 0) $start_tag = 7;
				if ($end_tag == 0) $end_tag = 7;
				$x1 = (($start_tag - 1) * $tag_weite) + 1;
				//$wd_weite = (($end_tag - $start_tag + 1) * $tag_weite) - 20;
				if (!($this->dbm->hasEditRights($this->range_id, $GLOBALS['auth']->auth['uid'], $t))) {
					// anscheinend nicht...
					$t->setDateType(0);
				}
				$wd_weite = (($end_tag - $start_tag + 1) * $tag_weite - 5);
				$js = "onClick=\"updateDetails('0','0','".$t->getTerminId()."');\"";
				$tooltip = tooltip(date('d.m.Y',$t->getVon()).' - '.date('d.m.Y',$t->getBis()),false);
				include('templates/wholeday_week.tpl');
				$y1 += $fulltime_hoehe;
			}
			// Container schliessen...
			echo "</DIV>\n";
		}
		
		// 24-Stunden
		for ($i=$start_stunde; $i<24; $i++) {
			$zeit_y1 = ($i * 60) - ($start_stunde * 60) + $start_offset;
			$zeit_y2 = (($i + 1) * 60) - ($start_stunde * 60) + $start_offset;

			// Marikierung fuer die volle Stunde
			if ($i != $start_stunde)
				include('templates/hour_line_week.tpl');
			// aktuelle Stunde am Tag
			if ($i == date("G",time()))
				include('templates/actual_hour_week.tpl');
			$hour = str_pad($i,2,"0",STR_PAD_LEFT);
			include('templates/hour_week.tpl');
		}

		
		$t_dates = $this->dc->weekDaysComputed($this_monday, $this_sunday, $start_stunde, $min_hoehe, $tag_weite, $zeit_weite, $start_offset, TRUE);
		if (count($t_dates) > 0) {
			foreach ($t_dates as $t) {
				// for display purposes
				if (!($this->config->get('tag_overlapping_dates'))) $t->setOverlapp(FALSE);
				$t_title = htmlReady($t->getTitle());
				$t_ort = htmlReady($t->getOrt());
				$t_content = $t->getContent();
				if ($t_content && strlen($t_content)>50) $t_content = "<BR>".substr(kill_format($this->kill_tags($t->getContent())), 0, 50) . "...";
				//$t_color = ($t->getOverlapp() ? '#FF4949' : $t->getColor());

				$js = "onClick=\"updateDetails('0','0','".$t->getTerminId()."');\"";

				// for display purposes
				$delta_y = $t->getHoehe();
                                $delta_y = ($delta_y < $min_hoehe ? $min_hoehe : $delta_y);
                                $delta_y -= 2;
				$tmp_tag_weite = $t->getWeite();
                                $tmp_tag_weite -=5;
				$x1 = $t->getX();
				$y1 = $t->getY();
				if (date('d.m.Y',$t->getVon()) == date('d.m.Y',$t->getBis())) 
					$tooltip = tooltip(date('H:i',$t->getVon()).' - '.date('H:i',$t->getBis()),false);
				else
					$tooltip = tooltip(date('d.m.Y H:i',$t->getVon()).' - '.date('d.m.Y H:i',$t->getBis()),false);
				include('templates/single_weekday.tpl');
			}
		}

		echo "</DIV>\n";
		echo "
<SCRIPT TYPE=\"text/javascript\">
Droppables.add('weekdrop', {
  accept: 'draggable'
});
</SCRIPT>
";
	}

	function daily_view() {
		$datum = trim($_REQUEST['datum']);
		if (!$datum) $datum = time();

		include('templates/details.tpl');
 
		$link_zurueck = PluginEngine::getLink($this,array("datum"=>strtotime("-1 day", $datum), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$link_vor = PluginEngine::getLink($this,array("datum"=>strtotime("+1 day", $datum), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$today_link = PluginEngine::getLink($this,array("datum"=>time(), "plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
		$self_link = PluginEngine::getLink($this,array("plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));

		//echo "<DIV STYLE=\"text-align:right; font-size:0.8em;\"><A HREF=\"".$GLOBALS['ABSOLUTE_URI_STUDIP'].$this->getPluginpath()."/download.php?datum=$datum&modus=day&range_id=".$GLOBALS['SessSemName'][1]."\" TARGET=\"pdf\">PDF-Export <IMG SRC=\"".$GLOBALS['ASSETS_URL']."/images/pdf-icon.gif\" BORDER=\"0\"></A></DIV>\n";

		include('templates/header_day.tpl');


		$start_stunde = $this->config->get('start_time');
		$von = strtotime(date("d.m.Y ".$start_stunde.":0:0",$datum));
		$von_fulltime = strtotime(date("d.m.Y 00:00:00",$datum));
		$bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$datum)));

		if ($_REQUEST['listview'] == '1') {
			$this->list_view($von, $bis);
		}

		$fulltime_dates = $this->dbm->getFulltimeDatesInRange($von_fulltime, $bis, $this->range_id);

		$zeit_weite = 50;
		$zeit_hoehe = 60;
		$tag_weite = 1050;
		$min_weite = floor($tag_weite / 4);
		$min_hoehe = 50;
		$wotag_hoehe = 20;
		$fulltime_hoehe = 18; // ein einzelner Ganztaagstermin
		$ganztag_hoehe = (count($fulltime_dates) > 0 ? (count($fulltime_dates) * $fulltime_hoehe > 100 ? 100 : count($fulltime_dates) * $fulltime_hoehe + 10) : 0); // der gesamte Ganztagscontainer
		$start_offset = $wotag_hoehe + $ganztag_hoehe; // wotag_hoehe + x, falls ganztgige Ternube vorhanden, sonst nur wtag_hoehe
		$frame_weite = $tag_weite + $zeit_weite;
		$frame_hoehe = (24 - $start_stunde) * $zeit_hoehe + $start_offset;

		//$t_dates = $this->dbm->getDatesInRange($von, $bis, $GLOBALS['SessSemName'][1], TRUE);
		
		echo "<DIV ID=\"daydrop\" STYLE=\"position:relative; width:".$frame_weite."px; min-width:".$frame_weite."px; max-width:".$frame_weite."px; height:".($frame_hoehe + 50)."px; min-height:".($frame_hoehe + 50)."px; max-height:".($frame_hoehe + 50)."px;\">\n";

		$create_link = PluginEngine::getLink($this,array("datum"=>$datum,"plugin_subnavi_params"=>"new_date"));
                $abort_link = PluginEngine::getLink($this,array("datum"=>$datum,"plugin_subnavi_params"=>$GLOBALS['plugin_subnavi_params']));
                if ($this->config->get('quick_create_date'))
                        include('templates/new_date_draggable.tpl');


		// Wochentage Montag - Sonntag
		echo "  <DIV ID=\"weekday\" CLASS=\"steel1\" STYLE=\"text-align:left; position:absolute; top:0px; left:".$wotag_x1."px; width:".$tag_weite."px; min-width:".$tag_weite."px; max-width:".$tag_weite."px; height:20px; min-height:20px; max-height:20px; border-bottom-width:1px; border-bottom-style:solid; border-bottom-color:black;\">\n";
		echo "    &nbsp;\n";
		echo "  </DIV>\n";

		// Falls es ganztaegige Termine gibt, werden sie gesondert dargestellt
		if (count($fulltime_dates) > 0) {
			$zeit_y1 = $wotag_hoehe;
			$zeit_y2 = $start_offset;
			include('templates/hour_wholeday_day.tpl');
			include('templates/wholeday_container_day.tpl');
			$y1 = 0;
			foreach ($fulltime_dates as $t) {
				$x1 = 1;
				$wd_weite = $tag_weite - $zeit_weite - 5;
				if (!($this->dbm->hasEditRights($this->range_id, $GLOBALS['auth']->auth['uid'], $t))) {
					// anscheinend nicht...
					$t->setDateType(0);
				}
				$js = "onClick=\"updateDetails('0','0','".$t->getTerminId()."');\"";
				$tooltip = tooltip(date('d.m.Y',$t->getVon()).' - '.date('d.m.Y',$t->getBis()),false);
				include('templates/wholeday_day.tpl');
				$y1 += $fulltime_hoehe;
			}
			// Container schliessen...
			echo "</DIV>\n";
		}
	
		// 24-Stunden
		for ($i=$start_stunde; $i<24; $i++) {
			$zeit_y1 = ($i * 60) - ($start_stunde * 60) + $start_offset;
			$zeit_y2 = (($i + 1) * 60) - ($start_stunde * 60) + $start_offset;

			// Markierungen fuer die volle Stunde
			if ($i != $start_stunde) 
				include('templates/hour_line_day.tpl');
			// aktuelle Stunde am Tag
			if ($i == date("G",time()))
				include('templates/actual_hour_day.tpl');

			$hour = str_pad($i,2,"0",STR_PAD_LEFT);
			include('templates/hour_day.tpl');
		}

		$t_dates = $this->dc->daysComputed($von, $bis, $start_stunde, $min_hoehe, $tag_weite, $zeit_weite, $start_offset, TRUE);
		if (count($t_dates) > 0) {
			foreach ($t_dates as $t) {
				// for display purposes
				if (!($this->config->get('tag_overlapping_dates'))) $t->setOverlapp(FALSE);
				$t_title = htmlReady($t->getTitle());
				$t_ort = htmlReady($t->getOrt());
				$t_content = $t->getContent();
				if ($t_content && strlen($t_content)>100) $t_content = "<BR>".substr(kill_format($this->kill_tags($t_content)), 0, 100) . "...";
				//$t_color = ($t->getOverlapp() ? '#FF4949' : $t->getColor());

				$js = "onClick=\"updateDetails('0','0','".$t->getTerminId()."');\"";

				// for display purposes
				$delta_y = $t->getHoehe();
				$delta_y = ($delta_y < $min_hoehe ? $min_hoehe : $delta_y);
                                $delta_y -= 2;
				$tmp_tag_weite = $t->getWeite();
                                $tmp_tag_weite -=5;
				$x1 = $t->getX();
				$y1 = $t->getY();
				if (date('d.m.Y',$t->getVon()) == date('d.m.Y',$t->getBis()))
                                        $tooltip = tooltip(date('H:i',$t->getVon()).' - '.date('H:i',$t->getBis()),false);
                                else
                                        $tooltip = tooltip(date('d.m.Y H:i',$t->getVon()).' - '.date('d.m.Y H:i',$t->getBis()),false);
				include('templates/single_day.tpl');
			}
		}

		echo "</DIV>\n";
		echo "
<SCRIPT TYPE=\"text/javascript\">
Droppables.add('daydrop', {
  accept: 'draggable'
  /*onDrop: function(element) {
    $('weekday').update('Dropped one on me: ['+element.style.left+','+element.style.top+']');
  }*/
});
</SCRIPT>
";

	}


    /**
     * Create a 2D array from a CSV string
     *
     * @param mixed $data 2D array
     * @param string $delimiter Field delimiter
     * @param string $enclosure Field enclosure
     * @param string $newline Line seperator
     * @return
     */
    function parse($data, $delimiter = ',', $enclosure = '"', $newline = "\n"){
        $pos = $last_pos = -1;
        $end = strlen($data);
        $row = 0;
        $quote_open = false;
        $trim_quote = false;

        $return = array();

        // Create a continuous loop
        for ($i = -1;; ++$i){
            ++$pos;
            // Get the positions
            $comma_pos = strpos($data, $delimiter, $pos);
            $quote_pos = strpos($data, $enclosure, $pos);
            $newline_pos = strpos($data, $newline, $pos);

            // Which one comes first?
            $pos = min(($comma_pos === false) ? $end : $comma_pos, ($quote_pos === false) ? $end : $quote_pos, ($newline_pos === false) ? $end : $newline_pos);

            // Cache it
            $char = (isset($data[$pos])) ? $data[$pos] : null;
            $done = ($pos == $end);

            // It it a special character?
            if ($done || $char == $delimiter || $char == $newline){

                // Ignore it as we're still in a quote
                if ($quote_open && !$done){
                    continue;
                }

                $length = $pos - ++$last_pos;

                // Is the last thing a quote?
                if ($trim_quote){
                    // Well then get rid of it
                    --$length;
                }

                // Get all the contents of this column
                $return[$row][] = ($length > 0) ? str_replace($enclosure . $enclosure, $enclosure, substr($data, $last_pos, $length)) : '';

                // And we're done
                if ($done){
                    break;
                }

                // Save the last position
                $last_pos = $pos;

                // Next row?
                if ($char == $newline){
                    ++$row;
                }

                $trim_quote = false;
            }
            // Our quote?
            else if ($char == $enclosure){

                // Toggle it
                if ($quote_open == false){
                    // It's an opening quote
                    $quote_open = true;
                    $trim_quote = false;

                    // Trim this opening quote?
                    if ($last_pos + 1 == $pos){
                        ++$last_pos;
                    }

                }
                else {
                    // It's a closing quote
                    $quote_open = false;

                    // Trim the last quote?
                    $trim_quote = true;
                }

            }

        }

        return $return;
    }

}

?>
