<?php 
/**
* Plugin zum Verwalten eines Gruppenkalenders
*
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2008 Jan Kulmann <jankul@zmml.uni-bremen.de>
// ATTENTION: Please send ALL bug reports and security leaks directly to the author.
//            Thx!
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+


require_once("lib/visual.inc.php");
require_once('vendor/flexi/template_factory.php');

class Export {

	var $dc;
	var $config;
	var $dbm;
	var $range_id;
	var $date_colors;
	var $template_path;
	var $factory;

	var $php_tage; // = array("1"=>"Montag", "2"=>"Dienstag", "3"=>"Mittwoch", "4"=>"Donnerstag", "5"=>"Freitag", "6"=>"Samstag", "0"=>"Sonntag");
	var $php_tage_short;
	var $monate;

	function Export($dc, $config, $dbm, $range_id) { 
		$this->dc = $dc;
		$this->config = $config;
		$this->dbm = $dbm;
		$this->range_id = $range_id;
		include_once(dirname(__FILE__) . '/../include/config.inc.php');
		$this->date_colors = $DATE_COLORS;
		$this->php_tage = $PHP_TAGE;
		$this->php_tage_short = $PHP_TAGE_SHORT;
		$this->monate = $MONATE;
		$this->template_path = dirname(__FILE__) . '/../templates/flexi/export';
		$this->factory = new Flexi_TemplateFactory($this->template_path);
	}

	function pdfExportList($datum, $modus, $von=null, $bis=null) {
		if (!$datum) $datum = time();
		if ($modus == "weekly_view") {
	                $von = (date("w", $datum) != 1 ? $this->dc->lastMonday($datum) : $datum);
        	        $bis = (date("w", $datum) != 0 ? $this->dc->nextSunday($datum) : $datum);
		} else if ($modus == "daily_view") {
			$start_stunde = $this->config->get('start_time');
	                $von = strtotime(date("d.m.Y ".$start_stunde.":0:0",$datum));
        	        $bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$datum)));
		} else if ($modus == "monthly_view") {
			$last_date = $this->dc->lastDayOfMonth($datum);
	                $last_day_in_month = $last_date;
        	        if (date("w", $last_date) != 0) $last_date = $this->dc->nextSunday($last_date);
                	$current_date = $this->dc->firstDayOfMonth($datum);
	                $first_day_in_month = $current_date;
        	        if (date("w",$current_date) != 1) $current_date = $this->dc->lastMonday($current_date);
			$von = $current_date;
			$bis = $last_date;
		} else if ($modus == "yearly_view") {
			$von = strtotime(date("01.01.Y 00:00:00",$datum));
	                $bis = strtotime("+1 day",strtotime(date("31.12.Y 00:00:00",$datum)));
		}

		$t_dates = $this->dbm->getDatesInRange($von, $bis, $this->range_id, FALSE, 'date ASC');

		$template = $this->factory->open('pdf_listview');
		$template->set_attribute('von', $von);
		$template->set_attribute('bis', $bis);
		$template->set_attribute('php_tage_short', $this->php_tage_short);
		$template->set_attribute('t_dates', $t_dates);

		return $template->render();

	}

	function pdfExportYear($datum) {
		$first_day_in_year = strtotime(date("01.01.Y 00:00:00",$datum));
		$last_day_in_year = strtotime("+1 day",strtotime(date("31.12.Y 00:00:00",$datum)));

		$template = $this->factory->open('pdf_year');
		$template->set_attribute('von', $first_day_in_year);
		$template->set_attribute('bis', strtotime("-1 day",$last_day_in_year));

		$jahr = array();

		for ($month = 1; $month < 13; $month++) {
			$last_date = $this->dc->lastDayOfMonth(strtotime("01.".str_pad($month,2,"0",STR_PAD_LEFT).".".date("Y",$datum)));
			$current_date = strtotime("01.".str_pad($month,2,"0",STR_PAD_LEFT).".".date("Y",$datum));
			$monat = array();
			$counter = 1;
			while ($current_date <= $last_date) {
				$von = strtotime(date("d.m.Y 00:00:00",$current_date));
                                $bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$current_date)));
				$t_dates = $this->dbm->getDatesInRange($von , $bis, $this->range_id, FALSE, "date ASC");
				$termin_texte = array();
				foreach ($t_dates as $t) {
					array_push($termin_texte, array('title'=>utf8_encode($t->getTitle()), 'color'=>($this->config->get('use_pdf_colors') ? $this->date_colors[$t->getColor()] : "white")));
				}
				$monat[$counter] = array('tag'=>$this->php_tage_short[date("w",$current_date)], 'tag_nr'=>date("j",$current_date), 'termine'=>$termin_texte);
				$counter++;
				$current_date = strtotime("+1 day",$current_date);
			}
			$jahr[$month] = array('monat'=>utf8_encode(html_entity_decode($this->monate[$month])), 'color'=>($this->config->get('use_pdf_colors') ? '#D3D4FF' : 'white'), 'tage'=>$monat);
		}
		$template->set_attribute('use_pdf_colors', $this->config->get('use_pdf_colors'));
		$template->set_attribute('jahr', $jahr);

		return $template->render();
	}

	function pdfExportMonth($datum) {
		$last_date = $this->dc->lastDayOfMonth($datum);
                $last_day_in_month = $last_date;
       	        if (date("w", $last_date) != 0) $last_date = $this->dc->nextSunday($last_date);
               	$current_date = $this->dc->firstDayOfMonth($datum);
                $first_day_in_month = $current_date;
       	        if (date("w",$current_date) != 1) $current_date = $this->dc->lastMonday($current_date);

		$template = $this->factory->open('pdf_month');
		$template->set_attribute('von', $current_date);
		$template->set_attribute('bis', $last_date);

		$counter = 0;
		$woche = 0;
		$tage = array();

		while ($current_date <= $last_date) {
                        $von = strtotime(date("d.m.Y 00:00:00",$current_date));
                        $bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$current_date)));
                        $t_dates = $this->dbm->getDatesInRange($von, $bis, $this->range_id, FALSE, "date ASC");

			if ($counter == 0) {
				$tage[$woche] = array();
			}
                        if ($counter == 7) {
                                $counter = 0;
				$woche++;
				$tage[$woche] = array();
                        }
                        $termin_texte = array();
                        if (count($t_dates) > 0) {
                                foreach ($t_dates as $t) {
                                        if (mktime(0,0,0,date('m',$current_date),date('d',$current_date),date('Y',$current_date)) > $t->getVon() ||
                                            mktime(0,0,0,date('m',$current_date),date('d',$current_date) + 1 ,date('Y',$current_date)) < $t->getBis()) {
                                                $anzeige_zeit = date("d.m.Y",$t->getVon())." - ".date("d.m.Y",$t->getBis());
                                        } else $anzeige_zeit = date("H:i",$t->getVon())." - ".date("H:i",$t->getBis());

					array_push($termin_texte, array('title'=>utf8_encode($t->getTitle()), 'zeit'=>$anzeige_zeit, 'color'=>($this->config->get('use_pdf_colors') ? $this->date_colors[$t->getColor()] : "white")));
                                }
                        }
                        // for display purposes
                        $today = (date("d.m.Y",time()) == date("d.m.Y",$current_date));
                        $color = ($current_date < $first_day_in_month || $current_date > $last_day_in_month ? "gray" : ($today ? ($this->config->get('use_pdf_colors') ? "red" : "black") : "black"));
			array_push($tage[$woche], array($this->php_tage_short[date("w",$current_date)].". ".date("d.m.Y",$current_date),$termin_texte, $color));


                        $current_date = strtotime("+1 day",$current_date);
                        $counter++;
			
                }

		$template->set_attribute('tage', $tage);

		return $template->render();

	}

	function pdfExportWeek($datum) {

		if (!$datum) $datum = time();
		$this_monday = (date("w", $datum) != 1 ? $this->dc->lastMonday($datum) : $datum);
		$this_sunday = (date("w", $datum) != 0 ? $this->dc->nextSunday($datum) : $datum);

		$fulltime_dates = $this->dbm->getFulltimeDatesInRange($this_monday, $this_sunday, $this->range_id);

		$start_stunde = $this->config->get('start_time');
                $zeit_hoehe = 60;
                $zeit_weite = 50;
                $tag_weite = 150;
                $min_weite = floor($tag_weite / 4);
                $min_hoehe = 50;
                $wotag_hoehe = 40;
                $fulltime_hoehe = 18; // ein einzelner Ganztaagstermin
                $ganztag_hoehe = (count($fulltime_dates) > 0 ? (count($fulltime_dates) * $fulltime_hoehe) : 0); // der gesamte Ganztagscontainer
                $start_offset = $wotag_hoehe + $ganztag_hoehe; // wotag_hoehe + x, falls ganztgige Ternube vorhanden, sonst nur wtag_hoehe
                $frame_weite = $tag_weite * 7 + $zeit_weite;
                $frame_hoehe = (24 - $start_stunde) * $zeit_hoehe + $start_offset;


		$o = "";
		$o .= "<fo:root xmlns:fo=\"http://www.w3.org/1999/XSL/Format\" xmlns:svg=\"http://www.w3.org/2000/svg\">
<fo:layout-master-set>
  <fo:simple-page-master master-name=\"one\"
                  page-width=\"42cm\"
                  page-height=\"".($frame_hoehe+200)."px\"
                  margin-top=\"1cm\"
                  margin-bottom=\"1cm\"
                  margin-left=\"1cm\"
                  margin-right=\"1cm\"
    >
    <fo:region-body margin-top=\"5pt\" margin-bottom=\"5pt\" margin-left=\"5pt\" margin-right=\"5pt\" />
  </fo:simple-page-master>
  <fo:simple-page-master master-name=\"normala4tabelle\"
                  page-width=\"210mm\"
                  page-height=\"297mm\"
                  margin-top=\"1cm\"
                  margin-bottom=\"1cm\"
                  margin-left=\"1cm\"
                  margin-right=\"1cm\"
    >
    <fo:region-body margin-top=\"5pt\" margin-bottom=\"5pt\" margin-left=\"5pt\" margin-right=\"5pt\" />
  </fo:simple-page-master>
</fo:layout-master-set>
<fo:page-sequence master-reference=\"one\">\n";

		$o .= "  <fo:flow flow-name=\"xsl-region-body\">\n";

		$o .= "     <fo:block font-variant=\"small-caps\" text-align=\"center\" font-size=\"18pt\" font-weight=\"bold\">".date("W",$datum).". Kalenderwoche, </fo:block>\n";
		$o .= "     <fo:block font-variant=\"small-caps\" text-align=\"center\" font-size=\"18pt\" font-weight=\"bold\" space-after.optimum=\"10pt\">vom ".date("d.m.Y",$this_monday)." bis zum ".date("d.m.Y",$this_sunday)."</fo:block>\n";

		$o .= "     <fo:block>
       <fo:instream-foreign-object>
          <svg:svg width=\"$frame_weite\" height=\"$frame_hoehe\">
            <svg:g style=\"fill:white; stroke:#000000\">
                <svg:rect x=\"0\" y=\"0\" width=\"$frame_weite\" height=\"$frame_hoehe\"/>
            </svg:g>
            <svg:line x1=\"0\" y1=\"".$wotag_hoehe."\" x2=\"1100\" y2=\"".$wotag_hoehe."\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>";

		$o .= "<svg:line x1=\"".$zeit_weite."\" y1=\"0\" x2=\"".$zeit_weite."\" y2=\"$frame_hoehe\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>\n";

		for ($i=0; $i<7; $i++) {
			$o .= "<svg:line x1=\"".(50 + $i * $tag_weite)."\" y1=\"0\" x2=\"".(50 + $i * $tag_weite)."\" y2=\"$frame_hoehe\" style=\"stroke:rgb(99,99,99);stroke-dasharray:4;stroke-width:0.1mm\"/>\n";
			$o .= "<svg:line x1=\"".(50 + $i * $tag_weite)."\" y1=\"0\" x2=\"".(50 + $i * $tag_weite)."\" y2=\"$wotag_hoehe\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>\n";
		}

		// 24-Stunden
                for ($i=$start_stunde; $i<24; $i++) {
                        $zeit_y1 = ($i * 60) - ($start_stunde * 60) + $start_offset;
                        $zeit_y2 = (($i + 1) * 60) - ($start_stunde * 60) + $start_offset;

                        // Marikierung fuer die volle Stunde
                        //if ($i != $start_stunde)
			$o .= "<svg:line x1=\"0\" y1=\"".$zeit_y1."\" x2=\"1100\" y2=\"".$zeit_y1."\" style=\"stroke:rgb(99,99,99);stroke-dasharray:4;stroke-width:0.1mm\"/>\n";
			$o .= "<svg:line x1=\"0\" y1=\"".$zeit_y1."\" x2=\"".$zeit_weite."\" y2=\"".$zeit_y1."\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>\n";
                        $hour = str_pad($i,2,"0",STR_PAD_LEFT);
			$o .= "<svg:text x=\"5\" y=\"".($zeit_y1 + 20)."\" style=\"font-family:Verdana;font-size:18\">$hour</svg:text>\n";
			$o .= "<svg:text x=\"5\" y=\"".($zeit_y1 + 40)."\" style=\"font-family:Verdana;font-size:14\">Uhr</svg:text>\n";
                }

		$akt_tag = $this_monday;
                for ($i=0; $i<7; $i++) {
                        $today = (date("d.m.Y",time()) == date("d.m.Y",$akt_tag));
			if (!$this->config->get('use_pdf_colors')) $today = FALSE;
                        $wotag_x1 = ($i * $tag_weite) + $zeit_weite;
			$o .= "<svg:text x=\"".($wotag_x1 + 5)."\" y=\"20\" style=\"font-family:Verdana;font-size:18".($today ? ";font-weight:bold;fill:red" : "")."\">".$this->php_tage[date('w', $akt_tag)]."</svg:text>\n";
			$o .= "<svg:text x=\"".($wotag_x1 + 5)."\" y=\"35\" style=\"font-family:Verdana;font-size:14\">".date('d.m.Y', $akt_tag)."</svg:text>\n";
			$akt_tag = strtotime("+1 day", $akt_tag);
		}


		if (count($fulltime_dates) > 0) {
                        $zeit_y1 = $wotag_hoehe;
                        $zeit_y2 = $start_offset;
                        $y1 = $wotag_hoehe;
                        foreach ($fulltime_dates as $t) {
                                $start_tag = (date('z',$t->getVon()) < date('z',$this_monday) ? date('w',$this_monday) : date('w',$t->getVon()));
                                $end_tag = (date('z',$t->getBis()) > date('z',$this_sunday) ? date('w',$this_sunday) : date('w',$t->getBis()));
                                if ($start_tag == 0) $start_tag = 7;
                                if ($end_tag == 0) $end_tag = 7;
                                $x1 = (($start_tag - 1) * $tag_weite) + 1 + $zeit_weite;
                                $wd_weite = (($end_tag - $start_tag + 1) * $tag_weite - 1);
				$title = utf8_encode(kill_format($t->getTitle()));
				$color = ($this->config->get('use_pdf_colors') ? $this->date_colors[$t->getColor()] : $this->date_colors['grau']);
				$o .= "<svg:g style=\"fill:".$color."; stroke:#000000\"><svg:rect x=\"$x1\" y=\"$y1\" width=\"$wd_weite\" height=\"$fulltime_hoehe\"/></svg:g>\n";
				$o .= "<svg:text x=\"".$x1."\" y=\"".($y1 + 14)."\" style=\"font-family:Verdana;font-size:12\">$title ".date('d.m.Y', $t->getVon())." - ".date('d.m.Y', $t->getBis())."</svg:text>\n";
                                $y1 += $fulltime_hoehe;
                        }
                }

		$t_dates = $this->dc->weekDaysComputed($this_monday, $this_sunday, $start_stunde, $min_hoehe, $tag_weite, $zeit_weite, $start_offset, TRUE);
                if (count($t_dates) > 0) {
			$counter = 0;
                        foreach ($t_dates as $t) {
				$counter++;
                                // for display purposes
                                if (!($this->config->get('tag_overlapping_dates'))) $overlapp = FALSE;
                                if ($t_content && strlen($t_content)>50) $t_content ="<BR>".substr(kill_format($t->getContent()), 0, 50) . "...";
                                $t_color = ($overlapp ? $this->date_colors['rot'] : $this->date_colors[$t->getColor()]);
				$t_color = ($this->config->get('use_pdf_colors') ? $t_color : $this->date_colors['grau']);
				$title = kill_format($t->getTitle());
				if ($t->getWeite() <= ($tag_weite / 3) && strlen($title) > 5)
					$title = substr($title, 0, 5)."...";
				else if ($t->getWeite() <= ($tag_weite / 2) && strlen($title) > 8)
					$title = substr($title, 0, 8)."...";
				else if ($t->getWeite() == $tag_weite && strlen($title) > 20)
					$title = substr($title, 0, 20)."...";
				else if ($t->getWeite() <= ($tag_weite / 4)) $title = "";
				$title = utf8_encode($title);

                                $x1 = $t->getX();
                                $y1 = $t->getY();
				$o .= "<svg:g style=\"fill:".$t_color."; stroke:#000000\"><svg:rect x=\"$x1\" y=\"$y1\" width=\"". $t->getWeite()."\" height=\"".$t->getHoehe()."\"/></svg:g>\n";
				$o .= "<svg:text x=\"".($x1 + 5)."\" y=\"".($y1 + 12)."\" style=\"font-family:Verdana;font-size:10\">$counter</svg:text>\n";
				$o .= "<svg:text x=\"".($x1 + 5)."\" y=\"".($y1 + 30)."\" style=\"font-family:Verdana;font-size:14\">$title</svg:text>\n";
                        }
                }



		$o .= "</svg:svg>
        </fo:instream-foreign-object>
     </fo:block>\n";

		$o .= "  </fo:flow>\n";
		$o .= "</fo:page-sequence>\n";

		if (count($t_dates) > 0) {
			$o .= "<fo:page-sequence master-reference=\"normala4tabelle\">\n";
			$o .= "  <fo:flow flow-name=\"xsl-region-body\">\n";
			$o .= "  <fo:block>\n";
			$o .= "    <fo:table table-layout=\"fixed\" width=\"100%\" space-after.optimum=\"10pt\">\n";
			$o .= "      <fo:table-column column-width=\"10mm\"/>\n";
			$o .= "      <fo:table-column column-width=\"180mm\"/>\n";
			$o .= "      <fo:table-body>\n";
			$counter = 0;
                        foreach ($t_dates as $t) {
				$counter++;
				$t_title = utf8_encode(kill_format($t->getTitle()));
				if ($t->getOrt())
					$t_ort = utf8_encode(kill_format($t->getOrt()));
				if ($t->getContent())
	                                $t_content = utf8_encode(kill_format($t->getContent()));
				$tag =  date('d.m.Y H:i', $t->getVon())." - ";
				$tag .= (date('d.m.Y', $t->getVon()) == date('d.m.Y', $t->getBis()) ? date('H:i', $t->getBis()) : date('d.m.Y H:i', $t->getBis()));
				$o .= "      <fo:table-row>\n";
				$o .= "        <fo:table-cell border-bottom-width=\"0.1mm\" border-bottom-style=\"solid\">\n";
				$o .= "          <fo:block space-before.optimum=\"10pt\" font-size=\"10pt\" font-weight=\"bold\">$counter.</fo:block>\n";
				$o .= "        </fo:table-cell>\n";
				$o .= "        <fo:table-cell border-bottom-width=\"0.1mm\" border-bottom-style=\"solid\">\n";
				$o .= "          <fo:block space-before.optimum=\"10pt\" font-size=\"10pt\" font-weight=\"bold\">$t_title</fo:block>\n";
				$o .= "        </fo:table-cell>\n";
				$o .= "      </fo:table-row>\n";
				$o .= "      <fo:table-row>\n";
				$o .= "        <fo:table-cell>\n";
				$o .= "          <fo:block font-size=\"10pt\"></fo:block>\n";
				$o .= "        </fo:table-cell>\n";
				$o .= "        <fo:table-cell>\n";
				$o .= "          <fo:block font-size=\"10pt\">".$tag."</fo:block>\n";
				$o .= "        </fo:table-cell>\n";
				$o .= "      </fo:table-row>\n";
				if ($t->getOrt()) {
	                        	$o .= "      <fo:table-row>\n";
					$o .= "        <fo:table-cell>\n";
					$o .= "          <fo:block font-size=\"10pt\"></fo:block>\n";
					$o .= "        </fo:table-cell>\n";
					$o .= "        <fo:table-cell>\n";
					$o .= "          <fo:block font-size=\"10pt\">Ort: ".$t_ort."</fo:block>\n";
					$o .= "        </fo:table-cell>\n";
					$o .= "      </fo:table-row>\n";
				}
			}
			$o .= "      </fo:table-body>\n";
			$o .= "    </fo:table>\n";
			$o .= "  </fo:block>\n";
			$o .= "  </fo:flow>\n";
			$o .= "</fo:page-sequence>\n";
                }
	

		//$o .= "  </fo:flow>
		$o .= "</fo:root>";

		return $o;

	}

	function pdfExportDay($datum) {

		if (!$datum) $datum = time();

		$start_stunde = $this->config->get('start_time');
                $von = strtotime(date("d.m.Y ".$start_stunde.":0:0",$datum));
                $bis = strtotime("+1 day",strtotime(date("d.m.Y 00:00:00",$datum)));

                //$fulltime_dates = $this->dbm->getFulltimeDatesInRange($von, $bis, $GLOBALS['SessSemName'][1]);
                $fulltime_dates = $this->dbm->getFulltimeDatesInRange($von, $bis, $this->range_id);

                $zeit_weite = 50;
                $zeit_hoehe = 60;
                $tag_weite = 1050;
                $min_weite = floor($tag_weite / 4);
                $min_hoehe = 50;
                $wotag_hoehe = 20;
                $fulltime_hoehe = 18; // ein einzelner Ganztaagstermin
                $ganztag_hoehe = (count($fulltime_dates) > 0 ? count($fulltime_dates) * $fulltime_hoehe : 0); // der gesamte Ganztagscontainer
                $start_offset = $wotag_hoehe + $ganztag_hoehe; // wotag_hoehe + x, falls ganztgige Ternube vorhanden, sonst nur wtag_hoehe
                //$frame_weite = $tag_weite + $zeit_weite;
                $frame_weite = $tag_weite;
                $frame_hoehe = (24 - $start_stunde) * $zeit_hoehe + $start_offset;

                //$t_dates = $this->dbm->getDatesInRange($von, $bis, $GLOBALS['SessSemName'][1], TRUE);
                $t_dates = $this->dbm->getDatesInRange($von, $bis, $this->range_id, TRUE);



		$o = "";
		$o .= "<fo:root xmlns:fo=\"http://www.w3.org/1999/XSL/Format\" xmlns:svg=\"http://www.w3.org/2000/svg\">
<fo:layout-master-set>
  <fo:simple-page-master master-name=\"one\"
                  page-width=\"42cm\"
                  page-height=\"".($frame_hoehe+200)."px\"
                  margin-top=\"1cm\"
                  margin-bottom=\"1cm\"
                  margin-left=\"1cm\"
                  margin-right=\"1cm\"
    >
    <fo:region-body margin-top=\"5pt\" margin-bottom=\"5pt\" margin-left=\"5pt\" margin-right=\"5pt\" />
  </fo:simple-page-master>
  <fo:simple-page-master master-name=\"normala4tabelle\"
                  page-width=\"210mm\"
                  page-height=\"297mm\"
                  margin-top=\"1cm\"
                  margin-bottom=\"1cm\"
                  margin-left=\"1cm\"
                  margin-right=\"1cm\"
    >
    <fo:region-body margin-top=\"5pt\" margin-bottom=\"5pt\" margin-left=\"5pt\" margin-right=\"5pt\" />
  </fo:simple-page-master>
</fo:layout-master-set>
<fo:page-sequence master-reference=\"one\">\n";

		$o .= "  <fo:flow flow-name=\"xsl-region-body\">\n";

		$o .= "     <fo:block font-variant=\"small-caps\" text-align=\"center\" font-size=\"18pt\" font-weight=\"bold\">".date("W",$datum).". Kalenderwoche, </fo:block>\n";
		$o .= "     <fo:block font-variant=\"small-caps\" text-align=\"center\" font-size=\"18pt\" font-weight=\"bold\" space-after.optimum=\"10pt\">".$this->php_tage[date("w",$datum)].", ".date("d.m.Y",$datum)."</fo:block>\n";

		$o .= "     <fo:block>
       <fo:instream-foreign-object>
          <svg:svg width=\"$frame_weite\" height=\"$frame_hoehe\">
            <svg:g style=\"fill:white; stroke:#000000\">
                <svg:rect x=\"0\" y=\"0\" width=\"$frame_weite\" height=\"$frame_hoehe\"/>
            </svg:g>
            <svg:line x1=\"0\" y1=\"".$wotag_hoehe."\" x2=\"1100\" y2=\"".$wotag_hoehe."\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>";

		$o .= "<svg:line x1=\"".$zeit_weite."\" y1=\"0\" x2=\"".$zeit_weite."\" y2=\"$frame_hoehe\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>\n";

		// 24-Stunden
                for ($i=$start_stunde; $i<24; $i++) {
                        $zeit_y1 = ($i * 60) - ($start_stunde * 60) + $start_offset;
                        $zeit_y2 = (($i + 1) * 60) - ($start_stunde * 60) + $start_offset;

                        // Marikierung fuer die volle Stunde
                        //if ($i != $start_stunde)
			$o .= "<svg:line x1=\"0\" y1=\"".$zeit_y1."\" x2=\"1100\" y2=\"".$zeit_y1."\" style=\"stroke:rgb(99,99,99);stroke-dasharray:4;stroke-width:0.1mm\"/>\n";
			$o .= "<svg:line x1=\"0\" y1=\"".$zeit_y1."\" x2=\"".$zeit_weite."\" y2=\"".$zeit_y1."\" style=\"stroke:rgb(99,99,99);stroke-width:0.5mm\"/>\n";
                        $hour = str_pad($i,2,"0",STR_PAD_LEFT);
			$o .= "<svg:text x=\"5\" y=\"".($zeit_y1 + 20)."\" style=\"font-family:Verdana;font-size:18\">$hour</svg:text>\n";
			$o .= "<svg:text x=\"5\" y=\"".($zeit_y1 + 40)."\" style=\"font-family:Verdana;font-size:14\">Uhr</svg:text>\n";
                }

		if (count($fulltime_dates) > 0) {
                        $zeit_y1 = $wotag_hoehe;
                        $zeit_y2 = $start_offset;
                        $y1 = $wotag_hoehe;
                        foreach ($fulltime_dates as $t) {
				$x1 = $zeit_weite;
                                $wd_weite = $tag_weite - $zeit_weite;
				$title = utf8_encode(kill_format($t->getTitle()));
				$color = ($this->config->get('use_pdf_colors') ? $this->date_colors[$t->getColor()] : $this->date_colors['grau']);
				$o .= "<svg:g style=\"fill:".$color."; stroke:#000000\"><svg:rect x=\"$x1\" y=\"$y1\" width=\"$wd_weite\" height=\"$fulltime_hoehe\"/></svg:g>\n";
				$o .= "<svg:text x=\"".$x1."\" y=\"".($y1 + 14)."\" style=\"font-family:Verdana;font-size:12\">$title ".date('d.m.Y', $t->getVon())." - ".date('d.m.Y', $t->getBis())."</svg:text>\n";
                                $y1 += $fulltime_hoehe;
                        }
                }

		$t_dates = $this->dc->daysComputed($von, $bis, $start_stunde, $min_hoehe, $tag_weite, $zeit_weite, $start_offset, TRUE);
                if (count($t_dates) > 0) {
			$counter = 0;
                        foreach ($t_dates as $t) {
                                // for display purposes
                                if (!($this->config->get('tag_overlapping_dates'))) $overlapp = FALSE;
                                if ($t_content && strlen($t_content)>50) $t_content ="<BR>".substr(kill_format($t->getContent()), 0, 50) . "...";
                                $t_color = ($overlapp ? $this->date_colors['rot'] : $this->date_colors[$t->getColor()]);
				$t_color = ($this->config->get('use_pdf_colors') ? $t_color : $this->date_colors['grau']);
				$title = kill_format($t->getTitle());
				/*if ($t->getWeite() <= ($tag_weite / 3) && strlen($title) > 5)
					$title = substr($title, 0, 5)."...";
				else if ($t->getWeite() <= ($tag_weite / 2) && strlen($title) > 8)
					$title = substr($title, 0, 8).".i.";
				else if ($t->getWeite() == $tag_weite && strlen($title) > 20)
					$title = substr($title, 0, 20)."...";
				else if ($t->getWeite() <= ($tag_weite / 4)) $title = "";*/
				$title = utf8_encode($title);

                                $x1 = $t->getX();
                                $y1 = $t->getY();
				$o .= "<svg:g style=\"fill:".$t_color."; stroke:#000000\"><svg:rect x=\"$x1\" y=\"$y1\" width=\"". $t->getWeite()."\" height=\"".$t->getHoehe()."\"/></svg:g>\n";
				//$o .= "<svg:text x=\"".($x1 + 5)."\" y=\"".($y1 + 12)."\" style=\"font-family:Verdana;font-size:10\">$counter</svg:text>\n";
				$o .= "<svg:text x=\"".($x1 + 5)."\" y=\"".($y1 + 15)."\" style=\"font-family:Verdana;font-size:14\">$title</svg:text>\n";
                        }
                }



		$o .= "</svg:svg>
        </fo:instream-foreign-object>
     </fo:block>\n";

		$o .= "  </fo:flow>\n";
		$o .= "</fo:page-sequence>\n";


		//$o .= "  </fo:flow>
		$o .= "</fo:root>";

		return $o;

	}

}

?>
